#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>

class WebView;

class MainWindow : public QMainWindow {

    Q_OBJECT

    public:
        explicit MainWindow(QWidget *parent = 0);
        virtual ~MainWindow();

#ifdef Q_WS_MAEMO_5
    private slots:
        void showAbout();
        void loadFinished(bool success = true);
        void setDisplayOrientation(Qt::WidgetAttribute orientation);
#endif

    private:
        WebView *m_webView;
};

#endif // MAINWINDOW_H
